summaryrefslogtreecommitdiffstats
path: root/generic/tcl.h
diff options
context:
space:
mode:
authorstanton <stanton>1999-06-17 19:32:14 (GMT)
committerstanton <stanton>1999-06-17 19:32:14 (GMT)
commit132b0b161f32aebd943a596184fdda97aa960c7d (patch)
tree356c44709bbda344154f1a4fe7811fabda634581 /generic/tcl.h
parent0db76eb23cf35b0d912eb915711eecbe51c65ac1 (diff)
downloadtcl-132b0b161f32aebd943a596184fdda97aa960c7d.zip
tcl-132b0b161f32aebd943a596184fdda97aa960c7d.tar.gz
tcl-132b0b161f32aebd943a596184fdda97aa960c7d.tar.bz2
* generic/tclTest.c:
* generic/tclRegexp.h: * generic/tclRegexp.c: * generic/tcl.h: * generic/tcl.decls: Renamed Tcl_RegExpMatchObj to Tcl_RegExpExecObj and added a new Tcl_RegExpMatchObj that is equivalent to Tcl_RegExpMatch. Added public macros for the regexp compile/execute flags. Changed to store either an object pointer or a string pointer in the TclRegexp structure. Changed to avoid adding a reference to the object or copying the string.
Diffstat (limited to 'generic/tcl.h')
-rw-r--r--generic/tcl.h35
1 files changed, 26 insertions, 9 deletions
diff --git a/generic/tcl.h b/generic/tcl.h
index 2c7ea05..7d9fe91 100644
--- a/generic/tcl.h
+++ b/generic/tcl.h
@@ -12,7 +12,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tcl.h,v 1.45 1999/06/10 04:28:49 stanton Exp $
+ * RCS: @(#) $Id: tcl.h,v 1.46 1999/06/17 19:32:14 stanton Exp $
*/
#ifndef _TCL
@@ -392,24 +392,41 @@ typedef struct Tcl_Var_ *Tcl_Var;
* matches */
/*
+ * The following flag is experimental and only intended for use by Expect. It
+ * will probably go away in a later release.
+ */
+
+#define TCL_REG_BOSONLY 002000 /* prepend \A to pattern so it only
+ * matches at the beginning of the
+ * string. */
+
+/*
+ * Flags values passed to Tcl_RegExpExecObj.
+ */
+
+#define TCL_REG_NOTBOL 0001 /* Beginning of string does not match ^. */
+#define TCL_REG_NOTEOL 0002 /* End of string does not match $. */
+
+/*
* Structures filled in by Tcl_RegExpInfo. Note that all offset values are
* relative to the start of the match string, not the beginning of the
* entire string.
*/
typedef struct Tcl_RegExpIndices {
- long start; /* character offset of first character in match */
- long end; /* character offset of first character after the
+ long start; /* character offset of first character in match */
+ long end; /* character offset of first character after the
* match. */
} Tcl_RegExpIndices;
typedef struct Tcl_RegExpInfo {
- int nsubs; /* number of subexpressions in the
- * compiled expression*/
- Tcl_RegExpIndices *matches; /* array of nsubs match offset
- * pairs */
- long extendStart; /* The offset at which a subsequent
- * match might begin. */
+ int nsubs; /* number of subexpressions in the
+ * compiled expression */
+ Tcl_RegExpIndices *matches; /* array of nsubs match offset
+ * pairs */
+ long extendStart; /* The offset at which a subsequent
+ * match might begin. */
+ long reserved; /* Reserved for later use. */
} Tcl_RegExpInfo;
/*